#include "vtkPseudoReader.h"

#include "vtkDataArraySelection.h"
#include "vtkInformation.h"
#include "vtkInformationVector.h"
#include "vtkMultiBlockDataSet.h"
#include "vtkObjectFactory.h"
#include "vtkStreamingDemandDrivenPipeline.h"

vtkCxxRevisionMacro(vtkPseudoReader, "$Revision: 1.00 $");
vtkStandardNewMacro(vtkPseudoReader);

//-----------------------------------------------------------------------------
vtkPseudoReader::vtkPseudoReader()
{
  this->SetNumberOfInputPorts(0);
  this->FileName = NULL;
  this->CellDataArraySelection = vtkDataArraySelection::New();
}

//-----------------------------------------------------------------------------
vtkPseudoReader::~vtkPseudoReader()
{
  this->SetFileName(0);
  this->CellDataArraySelection->Delete();
}

//-----------------------------------------------------------------------------
void vtkPseudoReader::PrintSelf(ostream &os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
  os << indent << "File Name: "
     << (this->FileName ? this->FileName : "(none)") << "\n";
}

//-----------------------------------------------------------------------------
// selection list handlers

int vtkPseudoReader::GetNumberOfCellArrays()
{
  return this->CellDataArraySelection->GetNumberOfArrays();
}

int vtkPseudoReader::GetCellArrayStatus(const char *name)
{
  return this->CellDataArraySelection->ArrayIsEnabled(name);
}

void vtkPseudoReader::SetCellArrayStatus(const char* name, int status)
{
  unsigned long int mTime = this->CellDataArraySelection->GetMTime();
  if(status)
    {
    this->CellDataArraySelection->EnableArray(name);
    }
  else
    {
    this->CellDataArraySelection->DisableArray(name);
    }
  if(mTime != this->CellDataArraySelection->GetMTime())
    {
    this->Modified();
    }
}

const char *vtkPseudoReader::GetCellArrayName(int index)
{
  return this->CellDataArraySelection->GetArrayName(index);
}

//-----------------------------------------------------------------------------
int vtkPseudoReader::RequestInformation(vtkInformation *vtkNotUsed(request),
  vtkInformationVector **vtkNotUsed(inputVector),
  vtkInformationVector *outputVector)
{
  static double timeSteps[6] = { 0.0, 0.2, 0.4, 0.6, 0.8, 1.0 };
  static double timeRange[2] = { 0.0, 1.0 };

  vtkInformation* outInfo = outputVector->GetInformationObject(0);
  outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(), timeSteps, 6);
  outInfo->Set(vtkStreamingDemandDrivenPipeline::TIME_RANGE(), timeRange, 2);

  static char arrayName[2] = { 0x40, 0 };
  arrayName[0]++;
  this->SetCellArrayStatus(arrayName, 1);
  return 1;
}

//-----------------------------------------------------------------------------
int vtkPseudoReader::RequestData(vtkInformation *vtkNotUsed(request),
  vtkInformationVector **vtkNotUsed(inputVector),
  vtkInformationVector *outputVector)
{
  vtkMultiBlockDataSet::SafeDownCast(outputVector->GetInformationObject(0)
    ->Get(vtkDataObject::DATA_OBJECT()))->Initialize();

  static char arrayName[2] = { 0x60, 0 };
  arrayName[0]++;
  this->SetCellArrayStatus(arrayName, 1);
  return 1;
}
